@@ -1,5 +1,5 @@
 import pathlib
-from typing import List, Optional
+from typing import List
 
 from flake8_fine_pytest.watchers.base import BaseWatcher
 from flake8_fine_pytest.utils import get_stem
@@ -26,6 +26,7 @@ def get_error_message(template: str, allowed_directories: List[str], filepath: s
 
 
 class ModulesStructureWatcher(BaseWatcher):
+    config_option = 'allowed_test_directories'
     error_template = (
         'FP003 File {filepath} is in the wrong directory. Allowed directories: {allowed_directories}'
     )
@@ -33,15 +34,12 @@ class ModulesStructureWatcher(BaseWatcher):
     def run(self) -> None:
         allowed_test_directories = self.options.allowed_test_directories
 
-        if self._should_check(allowed_test_directories) is False:
-            return None
-
         file_directory = get_file_directory(self.filename)
 
         if file_directory not in allowed_test_directories:
-            error_message = get_error_message(self.error_template, allowed_test_directories, self.filename)
-
+            error_message = get_error_message(
+                self.error_template,
+                allowed_test_directories,
+                self.filename,
+            )
             self.add_error((0, 0, error_message))
-
-    def _should_check(self, allowed_test_directories: Optional[List[str]]) -> bool:
-        return self._is_test_file(self.filename) and allowed_test_directories is not None
